@@ -6,7 +6,7 @@ test -z "$srcdir" && srcdir=.
 
 PKG_NAME="mate-calc"
 REQUIRED_AUTOMAKE_VERSION=1.7
-#REQUIRED_YELP_TOOLS_VERSION=3.1.1
+REQUIRED_YELP_TOOLS_VERSION=3.1.1
 
 (test -f $srcdir/configure.ac \
   && test -d $srcdir/src) || {
@@ -19,4 +19,10 @@ which mate-autogen || {
     echo "You need to install mate-common from the MATE git"
     exit 1
 }
+
+which yelp-build || {
+    echo "You need to install yelp-tools" 
+    exit 1
+}
+
 USE_MATE2_MACROS=1 USE_COMMON_DOC_BUILD=yes . mate-autogen
